@@ -70,5 +70,5 @@ def log_metrics(y_true, y_pred, task):
     return metrics
 
 
-def upload(version_id, metrics):
-    requests.put(f"http://localhost:5000/versions/results/{version_id}", data=metrics)
+def upload_metrics(experiment_id, metrics):
+    requests.put(f"http://localhost:8000/experiments/results/{experiment_id}", data=metrics)
