@@ -5,8 +5,7 @@ from sklearn.impute import SimpleImputer
 import pandas as pd
 from scipy import stats
 import numpy as np
-# import AutoClean
-# from AutoClean import AutoClean
+from AutoClean import AutoClean
 
 def remove_nan_values(**params):
     data = params['data']
@@ -159,6 +158,13 @@ def merge(**params):
     df = data.merge(**params['parameters'])
     return df
 
+# def split_data(**params):
+#     df_shuffled = df.sample(frac=1)
+# df_splits = np.array_split(df_shuffled, 2)
+# for df in df_splits:
+#     display(df)
+#     return 0
+
 def rename_columns(**params):
     data = params['data']
     dict = params['dict']
@@ -177,10 +183,10 @@ def clean_column_names(**params):
     data.rename(columns=lambda x: re.sub(match, "", str(x)))
     return data
 
-# def clean_data(**params):
-#     data = params['data']
-#     df = AutoClean(data)
-#     return df.output
+def clean_data(**params):
+    data = params['data']
+    df = AutoClean(data)
+    return df.output
 
 def clip(**params):
     data = params['data']
