@@ -1,7 +1,9 @@
 import huble
+#TODO: Edit imports
 model = huble.sklearn.random_forest(parameters={'criterion': 'gini', 'n_estimators': 100, 'max_depth': 'None', 'max_leaf_nodes': 'None', 'random_state': 'None'})
 data=huble.util.load_dataset('https://ipfs.filebase.io/ipfs/QmRspeqXi9J2PVTmXYwMaBif9dYWVkNhM8EFomUAfajnT1')
-data = huble.sklearn.drop_duplicates(data=data,parameters={'subset': [], 'keep': 'first', 'inplace': False, 'ignore_index': False})
+data = huble.sklearn.drop_duplicates(data=data,parameters={})
+#TODO: Check drop duplicates
 data = huble.sklearn.remove_mismatch_data(data=data, parameters={'exceptions': []})
 data = huble.sklearn.remove_outliers(data=data,columns=['Ticket'])
 data = huble.sklearn.drop_rows_columns(data=data,parameters={'labels': ['PassengerId', 'Pclass', 'Name'], 'axis': 0, 'inplace': False, 'errors': 'raise'})
