@@ -3,7 +3,7 @@ import sklearn
 import lightgbm as lgb
 import xgboost as xgb
 import catboost as cb
-
+from sklearn import ensemble
 #Classification
 
 def logistic_regression():
@@ -35,7 +35,7 @@ def decision_tree(**params):
     return model
 
 def random_forest(**params):
-    model = sklearn.ensemble.RandomForestClassifier(**params["parameters"])
+    model = ensemble.RandomForestClassifier(**params["parameters"])
     return model
 
 def gradient_boosting(**params):
